@@ -62,6 +62,12 @@ H5P_ZIP_READABLE = "H5P Zip"
 H5P_THUMBNAIL = "h5p_thumbnail"
 H5P_THUMBNAIL_READABLE = "H5P Thumbnail"
 
+QTI_ZIP = "qti"
+QTI_ZIP_READABLE = "QTI Zip"
+QTI_THUMBNAIL = "qti_thumbnail"
+QTI_THUMBNAIL_READABLE = "QTI Thumbnail"
+
+
 SLIDESHOW_IMAGE = "slideshow_image"
 SLIDESHOW_IMAGE_READABLE = "Slideshow Image"
 
@@ -96,6 +102,8 @@ choices = (
     (HTML5_THUMBNAIL, HTML5_THUMBNAIL_READABLE),
     (H5P_ZIP, H5P_ZIP_READABLE),
     (H5P_THUMBNAIL, H5P_THUMBNAIL_READABLE),
+    (QTI_ZIP, QTI_ZIP_READABLE),
+    (QTI_THUMBNAIL, QTI_THUMBNAIL_READABLE),
     (SLIDESHOW_IMAGE, SLIDESHOW_IMAGE_READABLE),
     (SLIDESHOW_THUMBNAIL, SLIDESHOW_THUMBNAIL_READABLE),
     (SLIDESHOW_MANIFEST, SLIDESHOW_MANIFEST_READABLE),
